@@ -44,7 +44,9 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         self._columns = None
 
     def _fetch_while(self, fn):
+        _logger.info("Commons - fetch while.... fn type - {}".format(type(fn)))
         while fn():
+            _logger.info("fetching next fetch more from fetch while")
             self._fetch_more()
             if fn():
                 time.sleep(self._poll_interval)
