@@ -77,11 +77,11 @@ class HiveParamEscaper(ParamEscaper):
             item = item.decode('utf-8')
         return "'{}'".format(
             item
-            .replace('\\', '\\\\')
-            .replace("'", "\\'")
-            .replace('\r', '\\r')
-            .replace('\n', '\\n')
-            .replace('\t', '\\t')
+                .replace('\\', '\\\\')
+                .replace("'", "\\'")
+                .replace('\r', '\\r')
+                .replace('\n', '\\n')
+                .replace('\t', '\\t')
         )
 
 
@@ -182,6 +182,9 @@ class Connection(object):
     def get_columns(self, database, table):
         return self._client.getColumns(schema=database, table=table)
 
+    def getColumns(self, database, table):
+        return self.get_columns(database, table)
+
     def commit(self):
         """Hive does not support transactions, so this does nothing."""
         pass
