@@ -272,8 +272,8 @@ class E6xDialect(default.DefaultDialect):
             rows = list()
             for column in columns:
                 row = dict()
-                row["col_name"] = column.getFieldName()
-                row["data_type"] = column.getFieldType()
+                row["col_name"] = column.fieldName
+                row["data_type"] = column.fieldType
                 rows.append(row)
 
             return rows
